==> apache-log4j-tools-0.5.0-src.zip: log4j-changelog/src/main/java/org/apache/logging/log4j/changelog/importer/MavenChangesImporterArgs.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.changelog.importer;

import java.nio.file.Path;
import java.util.Objects;

public final class MavenChangesImporterArgs {

    final Path changelogDirectory;

    final Path changesXmlFile;

    final int releaseVersionMajor;

    public MavenChangesImporterArgs(
            final Path changelogDirectory,
            final Path changesXmlFile,
            final int releaseVersionMajor) {

        // Check arguments
        Objects.requireNonNull(changelogDirectory, "changelogDirectory");
        Objects.requireNonNull(changesXmlFile, "changesXmlFile");
        if (releaseVersionMajor < 0) {
            final String message = String.format(
                    "was expecting `releaseVersionMajor >= 0`, found: %d",
                    releaseVersionMajor);
            throw new IllegalArgumentException(message);
        }

        // Set fields
        this.changelogDirectory = changelogDirectory;
        this.changesXmlFile = changesXmlFile;
        this.releaseVersionMajor = releaseVersionMajor;

    }

}

==> apache-log4j-tools-0.9.0-src.zip: log4j-changelog/src/main/java/org/apache/logging/log4j/changelog/importer/MavenChangesImporterArgs.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to you under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.logging.log4j.changelog.importer;

import java.nio.file.Path;
import java.util.Objects;

public final class MavenChangesImporterArgs {

    final Path changelogDirectory;

    final Path changesXmlFile;

    final int releaseVersionMajor;

    public MavenChangesImporterArgs(
            final Path changelogDirectory, final Path changesXmlFile, final int releaseVersionMajor) {

        // Check arguments
        Objects.requireNonNull(changelogDirectory, "changelogDirectory");
        Objects.requireNonNull(changesXmlFile, "changesXmlFile");
        if (releaseVersionMajor < 0) {
            final String message =
                    String.format("was expecting `releaseVersionMajor >= 0`, found: %d", releaseVersionMajor);
            throw new IllegalArgumentException(message);
        }

        // Set fields
        this.changelogDirectory = changelogDirectory;
        this.changesXmlFile = changesXmlFile;
        this.releaseVersionMajor = releaseVersionMajor;
    }
}
